<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sk">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../forms/aboutdialog.ui" line="14"/>
        <source>About Qmmp</source>
        <translation>O Qmmp</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="40"/>
        <source>About</source>
        <translation>O progarme</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="54"/>
        <source>Authors</source>
        <translation>Autori</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="82"/>
        <source>Thanks To</source>
        <translation>Poďakovanie</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="96"/>
        <source>License Agreement</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="61"/>
        <source>:/txt/authors_en.txt</source>
        <translation>:/txt/authors_sk.txt</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="62"/>
        <source>:/txt/thanks_en.txt</source>
        <translation>:/txt/thanks_sk.txt</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="81"/>
        <source>Qt-based Multimedia Player (Qmmp)</source>
        <translation>Qt-based Multimedia Player (Qmmp)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="82"/>
        <source>Version:</source>
        <translation>Verzia:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="83"/>
        <source>:txt/description_en.txt</source>
        <translation>:txt/description_sk.txt</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="84"/>
        <source>Input plugins:</source>
        <translation>Vstupné moduly:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="93"/>
        <source>Output plugins:</source>
        <translation>Výstupné moduly:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="102"/>
        <source>Visual plugins:</source>
        <translation>Vizualizačné moduly:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="111"/>
        <source>Effect plugins:</source>
        <translation>Moduly efektov:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="120"/>
        <source>General plugins:</source>
        <translation>Všebecné moduly:</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="68"/>
        <source>Translators</source>
        <translation>Prekladatelia</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="63"/>
        <source>:/txt/translators_en.txt</source>
        <translation>:/txt/translators_sk.txt</translation>
    </message>
</context>
<context>
    <name>ActionManager</name>
    <message>
        <location filename="../actionmanager.cpp" line="37"/>
        <source>&amp;Play</source>
        <translation>&amp;Hrať</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="37"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="38"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pozastaviť</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="38"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="39"/>
        <source>&amp;Stop</source>
        <translation>Za&amp;staviť</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="39"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="40"/>
        <source>&amp;Previous</source>
        <translation>&amp;Predchádzajúca</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="40"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="41"/>
        <source>&amp;Next</source>
        <translation>&amp;Nasledujúca</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="41"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="42"/>
        <source>&amp;Play/Pause</source>
        <translation>&amp;Hrať/Pozastaviť</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="42"/>
        <source>Space</source>
        <translation>Medzerník</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="43"/>
        <source>&amp;Jump to File</source>
        <translation>P&amp;resjočiť na súbor</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="43"/>
        <source>J</source>
        <translation>J</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="44"/>
        <source>&amp;Repeat Playlist</source>
        <translation>&amp;Opakovať playlist</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="44"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="45"/>
        <source>&amp;Repeat Track</source>
        <translation>&amp;Opakovať skladbu</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="45"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="46"/>
        <source>&amp;Shuffle</source>
        <translation>&amp;Zamiešať</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="46"/>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="47"/>
        <source>&amp;No Playlist Advance</source>
        <translation>&amp;Nepokročilý playlist</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="48"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="49"/>
        <source>&amp;Stop After Selected</source>
        <translation>&amp;Zastaviť po vybranej</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="50"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="51"/>
        <source>&amp;Clear Queue</source>
        <translation>&amp;Vyčistiť rad</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="51"/>
        <source>Alt+Q</source>
        <translation>Alt+Q</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="53"/>
        <source>Show Playlist</source>
        <translation>Ukázať playlist</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="53"/>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="54"/>
        <source>Show Equalizer</source>
        <translation>Ukázať ekvalizér</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="54"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="55"/>
        <source>Always on Top</source>
        <translation>Vždy na vrchu</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="56"/>
        <source>Put on All Workspaces</source>
        <translation>Dať na všetky plochy</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="57"/>
        <source>Double Size</source>
        <translation>Dvojitá veľkosť</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="57"/>
        <source>Meta+D</source>
        <translation>Meta+D</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="59"/>
        <source>&amp;Add File</source>
        <translation>&amp;Pridať súbor</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="59"/>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="60"/>
        <source>&amp;Add Directory</source>
        <translation>&amp;Pridať priečinok</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="60"/>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="61"/>
        <source>&amp;Add Url</source>
        <translation>&amp;Pridať URL</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="61"/>
        <source>U</source>
        <translation>U</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="62"/>
        <source>&amp;Remove Selected</source>
        <translation>Odst&amp;rániť vybraté</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="63"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="64"/>
        <source>&amp;Remove All</source>
        <translation>Odst&amp;rániť všetko</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="65"/>
        <source>&amp;Remove Unselected</source>
        <translation>Odst&amp;rániť nevybraté</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="67"/>
        <source>Remove unavailable files</source>
        <translation>Odstrániť nedostupné súbory</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="69"/>
        <source>Remove duplicates</source>
        <translation>Odstrániť duplikáty</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="70"/>
        <source>&amp;Queue Toggle</source>
        <translation>&amp;Zaradiť prepínanie</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="70"/>
        <source>Q</source>
        <translation>Q</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="71"/>
        <source>Invert Selection</source>
        <translation>Invertovať výber</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="72"/>
        <source>&amp;Select None</source>
        <translation>Zrušiť &amp;výber</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="73"/>
        <source>&amp;Select All</source>
        <translation>&amp;Vybrať všetko</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="74"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="75"/>
        <source>&amp;View Track Details</source>
        <translation>&amp;Zobraziť detaily o skladbe</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="75"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="77"/>
        <source>&amp;New List</source>
        <translation>&amp;Nový zoznam</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="77"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="78"/>
        <source>&amp;Delete List</source>
        <translation>&amp;Vymazať zoznam</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="78"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="79"/>
        <source>&amp;Load List</source>
        <translation>&amp;Načítať zoznam</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="79"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="80"/>
        <source>&amp;Save List</source>
        <translation>&amp;Uložiť zoznam</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="80"/>
        <source>Shift+S</source>
        <translation>Shift+S</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="81"/>
        <source>&amp;Select Next Playlist</source>
        <translation>&amp;Vybrať nasledujúci playlist</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="82"/>
        <source>Ctrl+PgDown</source>
        <translation>Ctrl+Page Down</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="83"/>
        <source>&amp;Select Previous Playlist</source>
        <translation>&amp;Vybrať predchádzajúci playlist</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="84"/>
        <source>Ctrl+PgUp</source>
        <translation>Ctrl+Page Up</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="85"/>
        <source>&amp;Show Playlists</source>
        <translation>&amp;kázať playlisty</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="86"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="88"/>
        <source>&amp;Settings</source>
        <translation>Na&amp;stavenia</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="88"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="89"/>
        <source>&amp;About</source>
        <translation>O progr&amp;ame</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="90"/>
        <source>&amp;About Qt</source>
        <translation>&amp;O Qt</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="91"/>
        <source>&amp;Exit</source>
        <translation>&amp;Ukončiť</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="91"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
</context>
<context>
    <name>AddUrlDialog</name>
    <message>
        <location filename="../forms/addurldialog.ui" line="13"/>
        <source>Enter URL to add</source>
        <translation>Pridať URL</translation>
    </message>
    <message>
        <location filename="../addurldialog.cpp" line="117"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="51"/>
        <source>&amp;Add</source>
        <translation>Prid&amp;ať</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="58"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušiť</translation>
    </message>
</context>
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="61"/>
        <source>Skip forward in playlist</source>
        <translation>Posunúť sa v plaliste</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="62"/>
        <source>Skip backwards in playlist</source>
        <translation>Vrátiť sa v playliste</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="55"/>
        <source>Start playing current song</source>
        <translation>Začať prehrávanie súčasnej piesne</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="54"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Nevyčisťovať playlist</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="56"/>
        <source>Pause current song</source>
        <translation>Pozastaviť súčasnú pieseň</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="57"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Pozastaviť ak hrá, inak hrať</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="58"/>
        <source>Stop current song</source>
        <translation>Zastaviť súčasnú pieseň</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="59"/>
        <source>Display Jump to File dialog</source>
        <translation>Zobraziť dialóg Preskočiť na súbor</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="60"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Nastaviť hlasitosť prehrávania (napríklad: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="63"/>
        <source>Show/hide application</source>
        <translation>Zobraziť/skryť program</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="64"/>
        <source>Display Add File dialog</source>
        <translation>Zobraziť dialóg Pridať súbor</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="65"/>
        <source>Display Add Directory dialog</source>
        <translation>Zobraziť dialóg Pridať priečinok</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../forms/configdialog.ui" line="735"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="740"/>
        <source>Filename</source>
        <translation>Názov súboru</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="429"/>
        <source>Artist</source>
        <translation>Interprét</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="75"/>
        <location filename="../configdialog.cpp" line="430"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="74"/>
        <source>Track</source>
        <translation>Skladba</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="76"/>
        <source>Disabled</source>
        <translation>Zakázané</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="244"/>
        <source>Transports</source>
        <translation>Protokoly</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="255"/>
        <source>Decoders</source>
        <translation>Dekodéry</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="265"/>
        <source>Engines</source>
        <translation>Prehrávače</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="372"/>
        <source>Misc</source>
        <translation>Rôzn.</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="431"/>
        <source>Title</source>
        <translation>Názov</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="432"/>
        <source>Track number</source>
        <translation>Číslo skladby</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="433"/>
        <source>Two-digit track number</source>
        <translation>Dvojmiestne číslo skladby</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="437"/>
        <source>Disc number</source>
        <translation>Číslo disku</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="441"/>
        <source>Condition</source>
        <translation>Stav</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="436"/>
        <source>Composer</source>
        <translation>Skladateľ</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="438"/>
        <source>File name</source>
        <translation>Názov súboru</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="439"/>
        <source>File path</source>
        <translation>Cesta k súboru</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="434"/>
        <source>Genre</source>
        <translation>Žáner</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="440"/>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="435"/>
        <source>Comment</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="14"/>
        <source>Qmmp Settings</source>
        <translation>Qmmp nastavenia</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="98"/>
        <source>Appearance</source>
        <translation>Vzhľad</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="107"/>
        <location filename="../forms/configdialog.ui" line="463"/>
        <location filename="../configdialog.cpp" line="366"/>
        <source>Playlist</source>
        <translation>Playlist</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="116"/>
        <source>Plugins</source>
        <translation>Moduly</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="125"/>
        <source>Advanced</source>
        <translation>Pokročilé</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="184"/>
        <source>Skins</source>
        <translation>Skiny</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="291"/>
        <source>Fonts</source>
        <translation>Písma</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="309"/>
        <source>Player:</source>
        <translation>Prehrávač:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="357"/>
        <source>Playlist:</source>
        <translation>Playlist:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="331"/>
        <location filename="../forms/configdialog.ui" line="379"/>
        <source>???</source>
        <translation>???</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1001"/>
        <source>Replay Gain</source>
        <translation>Zisk pri prehrávaní</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="249"/>
        <source>Miscellaneous</source>
        <translation>Rôzne</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="338"/>
        <location filename="../forms/configdialog.ui" line="386"/>
        <location filename="../forms/configdialog.ui" line="552"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="393"/>
        <source>Use bitmap font if available</source>
        <translation>Použiť bitmapové písmo, ak je dostupné</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="275"/>
        <source>Use skin cursors</source>
        <translation>Použiť kurzory zo skinu</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="152"/>
        <source>Shortcuts</source>
        <translation>Skratky</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="511"/>
        <source>Metadata</source>
        <translation>Metadáta</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="523"/>
        <source>Load metadata from files</source>
        <translation>Čítať metadáta zo súborov</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="533"/>
        <source>Song Display</source>
        <translation>Zobrazenie skladby</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="539"/>
        <source>Title format:</source>
        <translation>Formát titulku:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="580"/>
        <source>Show song numbers</source>
        <translation>Zobrazovať čísla piesní</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="587"/>
        <source>Show playlists</source>
        <translation>Zobrazovať playlisty</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="596"/>
        <source>Show popup information</source>
        <translation>Zobrazovať upozornenia s informáciami</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="628"/>
        <source>Show anchor</source>
        <translation>Zobrazovať ukotvenie</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="638"/>
        <source>Align song numbers</source>
        <translation>Zarovnať čísla piesní</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="686"/>
        <location filename="../forms/configdialog.ui" line="1153"/>
        <source>Preferences</source>
        <translation>Nastavenia</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="699"/>
        <location filename="../forms/configdialog.ui" line="761"/>
        <location filename="../forms/configdialog.ui" line="1166"/>
        <source>Information</source>
        <translation>Informácie</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="784"/>
        <source>Cover Image Retrieve</source>
        <translation>Získať obrázok obalu</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="790"/>
        <source>Use separate image files</source>
        <translation>Používať samostatné súbory obrázkov</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="800"/>
        <source>Include files:</source>
        <translation>Zahrnúť súbory:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="810"/>
        <source>Exclude files:</source>
        <translation>Vynechať súbory:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="822"/>
        <source>Recursive search depth:</source>
        <translation>Hĺbka rekurzívneho hľadania:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="867"/>
        <location filename="../configdialog.cpp" line="354"/>
        <source>Playback</source>
        <translation>Prehrávanie</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="873"/>
        <source>Continue playback on startup</source>
        <translation>Pri štarte pokračovať v prehrávaní</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1007"/>
        <source>Replay Gain mode:</source>
        <translation>Režim úpravy zisku pri prehrávaní:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1024"/>
        <source>Preamp:</source>
        <translation>Predzosilnenie:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1056"/>
        <location filename="../forms/configdialog.ui" line="1101"/>
        <source>dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1069"/>
        <source>Default gain:</source>
        <translation>Východzý zisk:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1121"/>
        <source>Use  peak info to prevent clipping</source>
        <translation>Použiť informáciu o vrchole k zabráneniu orezu</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1137"/>
        <source>Output:</source>
        <translation>Výstup:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1189"/>
        <source>Buffer size:</source>
        <translation>Veľkosť bufferu:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1202"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1238"/>
        <source>16-bit output</source>
        <translation>16bitový výstup</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1272"/>
        <source>Action</source>
        <translation>Činnosť</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1277"/>
        <source>Shortcut</source>
        <translation>Skratka</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1285"/>
        <source>Change shortcut...</source>
        <translation>Zmeniť skratku...</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="134"/>
        <source>Connectivity</source>
        <translation>Pripojenie k sieti</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="255"/>
        <location filename="../configdialog.cpp" line="360"/>
        <source>View</source>
        <translation>Zobrazenie</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="606"/>
        <source>Edit template</source>
        <translation>Upraviť šablónu</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="752"/>
        <source>File Dialog</source>
        <translation>Súborový dialóg</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="899"/>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="911"/>
        <source>Enable proxy usage</source>
        <translation>Povoliť používanie proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="918"/>
        <source>Proxy host name:</source>
        <translation>Adresa proxy:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="931"/>
        <source>Proxy port:</source>
        <translation>Port proxy:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="944"/>
        <source>Use authentication with proxy</source>
        <translation>Použiť autentifikáciu s proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="951"/>
        <source>Proxy user name:</source>
        <translation>Proxy použivateľské meno:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="964"/>
        <source>Proxy password:</source>
        <translation>Proxy heslo:</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="209"/>
        <source>Archived skin</source>
        <translation>Archivovaný skin</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="231"/>
        <source>Unarchived skin</source>
        <translation>Nearchivovaný skin</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="285"/>
        <source>Visualization</source>
        <translation>Vizualizácie</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="275"/>
        <source>Effects</source>
        <translation>Efekty</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="295"/>
        <source>General</source>
        <translation>Všeobecné</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="143"/>
        <location filename="../forms/configdialog.ui" line="1131"/>
        <source>Audio</source>
        <translation>Zvuk</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1231"/>
        <source>Use software volume control</source>
        <translation>Používať softwarové ovládanie hlasitosti</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="261"/>
        <source>Hide on close</source>
        <translation>Skryť pri zatvorení</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="268"/>
        <source>Start hidden</source>
        <translation>Spustiť skryté</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="559"/>
        <source>Convert underscores to blanks</source>
        <translation>Previesť podčiarknutia na medzery</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="566"/>
        <source>Convert %20 to blanks</source>
        <translation>Previesť %20 na mdezery</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="524"/>
        <source>Select Skin Files</source>
        <translation>Vybrať súbory skinov</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="525"/>
        <source>Skin files</source>
        <translation>Súbory skinov</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="215"/>
        <source>Add...</source>
        <translation>Pridať...</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="228"/>
        <source>Refresh</source>
        <translation>Obnoviť</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="573"/>
        <source>Show protocol</source>
        <translation>Zobraziť protokol</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="403"/>
        <source>Transparency</source>
        <translation>Priehľadnosť</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="409"/>
        <source>Main window</source>
        <translation>Hlavné okno</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="432"/>
        <location filename="../forms/configdialog.ui" line="456"/>
        <location filename="../forms/configdialog.ui" line="480"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="439"/>
        <source>Equalizer</source>
        <translation>Ekvalizér</translation>
    </message>
</context>
<context>
    <name>EqWidget</name>
    <message>
        <location filename="../eqwidget.cpp" line="43"/>
        <source>Equalizer</source>
        <translation>Ekvalizér</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="154"/>
        <location filename="../eqwidget.cpp" line="177"/>
        <source>preset</source>
        <translation>předvolba</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="261"/>
        <source>&amp;Load/Delete</source>
        <translation>&amp;Načíst/Odstranit</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="263"/>
        <source>&amp;Save Preset</source>
        <translation>&amp;Uložit předvolbu</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="265"/>
        <source>&amp;Save Auto-load Preset</source>
        <translation>Uložit &amp;automatickou předvolbu</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="267"/>
        <source>&amp;Import</source>
        <translation>&amp;Importovat</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="270"/>
        <source>&amp;Clear</source>
        <translation>&amp;Vynulovat</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="299"/>
        <source>Saving Preset</source>
        <translation>Uložení předvolby</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="300"/>
        <source>Preset name:</source>
        <translation>Název předvolby:</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="301"/>
        <source>preset #</source>
        <translation>předvolba #</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="392"/>
        <source>Import Preset</source>
        <translation>Importovat předvolbu</translation>
    </message>
</context>
<context>
    <name>JumpToTrackDialog</name>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="53"/>
        <source>Q</source>
        <translation>Q</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="54"/>
        <source>J</source>
        <translation>J</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="55"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="84"/>
        <location filename="../jumptotrackdialog.cpp" line="135"/>
        <source>Unqueue</source>
        <translation>Vyradiť</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="70"/>
        <location filename="../jumptotrackdialog.cpp" line="86"/>
        <location filename="../jumptotrackdialog.cpp" line="137"/>
        <source>Queue</source>
        <translation>Zaradiť</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="14"/>
        <source>Jump To Track</source>
        <translation>Preskočiť na skladbu</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="37"/>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="83"/>
        <source>Refresh</source>
        <translation>Obnoviť</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="96"/>
        <source>Jump To</source>
        <translation>Preskočiť na</translation>
    </message>
</context>
<context>
    <name>MainDisplay</name>
    <message>
        <location filename="../display.cpp" line="57"/>
        <source>Previous</source>
        <translation>Predchádzajúca</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="61"/>
        <source>Play</source>
        <translation>Hrať</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="64"/>
        <source>Pause</source>
        <translation>Pozastaviť</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="67"/>
        <source>Stop</source>
        <translation>Zastaviť</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="70"/>
        <source>Next</source>
        <translation>Nasledujúca</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="73"/>
        <source>Add file</source>
        <translation>Pridať súbor</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="80"/>
        <source>Equalizer</source>
        <translation>Ekvalizér</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="83"/>
        <source>Playlist</source>
        <translation>Playlist</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="88"/>
        <source>Repeat playlist</source>
        <translation>Opakovať playlist</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="91"/>
        <source>Shuffle</source>
        <translation>Zamiešať</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="101"/>
        <source>Volume</source>
        <translation>Hlasitosť</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="107"/>
        <source>Balance</source>
        <translation>Vyváženie</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="296"/>
        <source>Volume: %1%</source>
        <translation>Hlasitosť: %1%</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="300"/>
        <source>Balance: %1% right</source>
        <translation>Vyváženie: %1% vpravo</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="302"/>
        <source>Balance: %1% left</source>
        <translation>Vyváženie: %1% vľavo</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="304"/>
        <source>Balance: center</source>
        <translation>Vyváženie: stred</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="315"/>
        <source>Seek to: %1</source>
        <translation>Pretočiť na: %1</translation>
    </message>
</context>
<context>
    <name>MainVisual</name>
    <message>
        <location filename="../mainvisual.cpp" line="280"/>
        <source>Visualization Mode</source>
        <translation>Režim vizualizácií</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="283"/>
        <source>Analyzer</source>
        <translation>Analyzér</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="284"/>
        <source>Scope</source>
        <translation>Osciloskop</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="285"/>
        <source>Off</source>
        <translation>Vypnuté</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="292"/>
        <source>Analyzer Mode</source>
        <translation>Režim analyzéra</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="295"/>
        <source>Normal</source>
        <translation>Normálny</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="296"/>
        <source>Fire</source>
        <translation>Oheň</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="297"/>
        <source>Vertical Lines</source>
        <translation>Stĺpce</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="298"/>
        <source>Lines</source>
        <translation>Čiary</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="299"/>
        <source>Bars</source>
        <translation>Prúžky</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="312"/>
        <source>Peaks</source>
        <translation>Špičky</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="316"/>
        <source>Refresh Rate</source>
        <translation>Obnovovacia frekvencia</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="319"/>
        <source>50 fps</source>
        <translation>50 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="320"/>
        <source>25 fps</source>
        <translation>25 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="321"/>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="322"/>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="329"/>
        <source>Analyzer Falloff</source>
        <translation>Pokles analyzéra</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="332"/>
        <location filename="../mainvisual.cpp" line="346"/>
        <source>Slowest</source>
        <translation>Najpomaljšie</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="333"/>
        <location filename="../mainvisual.cpp" line="347"/>
        <source>Slow</source>
        <translation>Pomaly</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="334"/>
        <location filename="../mainvisual.cpp" line="348"/>
        <source>Medium</source>
        <translation>Stredne</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="335"/>
        <location filename="../mainvisual.cpp" line="349"/>
        <source>Fast</source>
        <translation>Rýchlo</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="336"/>
        <location filename="../mainvisual.cpp" line="350"/>
        <source>Fastest</source>
        <translation>Najrýchlejšie</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="343"/>
        <source>Peaks Falloff</source>
        <translation>Pokles špičiek</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="356"/>
        <source>Background</source>
        <translation>Pozadie</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="357"/>
        <source>Transparent</source>
        <translation>Priehľadné</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="245"/>
        <source>Choose a directory</source>
        <translation>Vyberte priečinok</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Select one or more files to open</source>
        <translation>Vyberte jeden alebo viac súborov na otvorenie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>View</source>
        <translation>Zobraziť</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="440"/>
        <source>Playlist</source>
        <translation>Playlist</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="510"/>
        <location filename="../mainwindow.cpp" line="536"/>
        <source>Playlist Files</source>
        <translation>Súbory playlistov</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="512"/>
        <source>Open Playlist</source>
        <translation>Otvoriť playlist</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="537"/>
        <source>Save Playlist</source>
        <translation>Uložiť playlist</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>All Supported Bitstreams</source>
        <translation>Všetky podporované formáty</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="460"/>
        <source>Tools</source>
        <translation>Nástroje</translation>
    </message>
</context>
<context>
    <name>PlayList</name>
    <message>
        <location filename="../playlist.cpp" line="204"/>
        <source>Sort List</source>
        <translation>Triediť zoznam</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="207"/>
        <location filename="../playlist.cpp" line="242"/>
        <source>By Title</source>
        <translation>Podľa názvu</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="211"/>
        <location filename="../playlist.cpp" line="246"/>
        <source>By Album</source>
        <translation>Podľa albumu</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="215"/>
        <location filename="../playlist.cpp" line="250"/>
        <source>By Artist</source>
        <translation>Podľa interpréta</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="219"/>
        <location filename="../playlist.cpp" line="254"/>
        <source>By Filename</source>
        <translation>Podľa názvu súboru</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="223"/>
        <location filename="../playlist.cpp" line="258"/>
        <source>By Path + Filename</source>
        <translation>Podľa cesty a názvu súboru</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="227"/>
        <location filename="../playlist.cpp" line="262"/>
        <source>By Date</source>
        <translation>Podľa dátumu</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="239"/>
        <source>Sort Selection</source>
        <translation>Potriediť výber</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="274"/>
        <source>Randomize List</source>
        <translation>Zamiešať zoznam</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="276"/>
        <source>Reverse List</source>
        <translation>Otočiť zoznam</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="550"/>
        <source>&amp;New PlayList</source>
        <translation>&amp;Nový playlist</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="177"/>
        <source>&amp;Copy Selection To</source>
        <translation>&amp;Skopírovať výber do</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="53"/>
        <source>Playlist</source>
        <translation>Playlist</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="231"/>
        <location filename="../playlist.cpp" line="266"/>
        <source>By Track Number</source>
        <translation>Podľa čísla skladby</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="283"/>
        <source>Actions</source>
        <translation>Činnosti</translation>
    </message>
</context>
<context>
    <name>PlayListBrowser</name>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="14"/>
        <source>Playlist Browser</source>
        <translation>Prehliadač playlistu</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="45"/>
        <source>New</source>
        <translation>Nový</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="52"/>
        <location filename="../playlistbrowser.cpp" line="39"/>
        <source>Delete</source>
        <translation>Vymazať</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="69"/>
        <location filename="../forms/playlistbrowser.ui" line="79"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../playlistbrowser.cpp" line="38"/>
        <source>Rename</source>
        <translation>Premenovať</translation>
    </message>
</context>
<context>
    <name>PlayListSelector</name>
    <message>
        <location filename="../playlistselector.cpp" line="51"/>
        <source>&amp;Load</source>
        <translation>&amp;Načítať</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="52"/>
        <source>&amp;Save As...</source>
        <translation>&amp;Uložiť ako...</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="54"/>
        <source>Rename</source>
        <translation>Premenovať</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="55"/>
        <source>&amp;Delete</source>
        <translation>&amp;Vymazať</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="112"/>
        <source>Rename Playlist</source>
        <translation>Premenovať playlist</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="112"/>
        <source>Playlist name:</source>
        <translation>Název playlistu:</translation>
    </message>
</context>
<context>
    <name>PopupSettings</name>
    <message>
        <location filename="../forms/popupsettings.ui" line="14"/>
        <source>Popup Information Settings</source>
        <translation>Nastavenie informácií v upozornení</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="75"/>
        <source>Show cover</source>
        <translation>Zobraziť obal</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="115"/>
        <source>Transparency:</source>
        <translation>Priehľadnosť:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="145"/>
        <source>Delay:</source>
        <translation>Oneskorenie:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="178"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="89"/>
        <source>Cover size:</source>
        <translation>Veľkosť obalu:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="29"/>
        <source>Template</source>
        <translation>Šablóna</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="58"/>
        <source>Reset</source>
        <translation>Zresetovať</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="65"/>
        <source>Insert</source>
        <translation>Vložiť</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="62"/>
        <source>Artist</source>
        <translation>Interprét</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="63"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="64"/>
        <source>Title</source>
        <translation>Názov</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="65"/>
        <source>Track number</source>
        <translation>Číslo skladby</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="66"/>
        <source>Two-digit track number</source>
        <translation>Dvojmiestne číslo skladby</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="67"/>
        <source>Genre</source>
        <translation>Žáner</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="68"/>
        <source>Comment</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="69"/>
        <source>Composer</source>
        <translation>Skladateľ</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="70"/>
        <source>Duration</source>
        <translation>Dĺžka</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="71"/>
        <source>Disc number</source>
        <translation>Číslo disku</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="72"/>
        <source>File name</source>
        <translation>Názov súboru</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="73"/>
        <source>File path</source>
        <translation>Cesta k súboru</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="74"/>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="75"/>
        <source>Condition</source>
        <translation>Stav</translation>
    </message>
</context>
<context>
    <name>PresetEditor</name>
    <message>
        <location filename="../forms/preseteditor.ui" line="14"/>
        <source>Preset Editor</source>
        <translation>Editor predvolieb</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="77"/>
        <source>Load</source>
        <translation>Načítať</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="84"/>
        <source>Delete</source>
        <translation>Vymazať</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="36"/>
        <source>Preset</source>
        <translation>Predvoľba</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="52"/>
        <source>Auto-preset</source>
        <translation>Automatická predvoľba</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="176"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Použitie: qmmp [možnosti] [súbory]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="177"/>
        <source>Options:</source>
        <translation>Možnosti:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="181"/>
        <source>Don&apos;t start the application</source>
        <translation>Nezapnúť program</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="183"/>
        <source>Print version number and exit</source>
        <translation>Vypísať číslo verzie a skončiť</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="184"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>Nápady, záplaty, hlásenie chýb posílejte na forkotov02@hotmail.ru (anglicky)</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="182"/>
        <source>Display this text and exit</source>
        <translation>Zobraziť tento text a skončiť</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="71"/>
        <source>Unknown command</source>
        <translation>Neznámý príkaz</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="189"/>
        <source>QMMP version:</source>
        <translation>Verzia QMMP:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="190"/>
        <source>Qt version:</source>
        <translation>Verzia Qt:</translation>
    </message>
</context>
<context>
    <name>ShortcutDialog</name>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="14"/>
        <source>Change Shortcut</source>
        <translation>Zmeniť skratku</translation>
    </message>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>Stlačte klávesovú kombináciu ktorú chcete priradiť</translation>
    </message>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="43"/>
        <source>Clear</source>
        <translation>Vyčistiť</translation>
    </message>
</context>
<context>
    <name>TextScroller</name>
    <message>
        <location filename="../textscroller.cpp" line="53"/>
        <source>Autoscroll Songname</source>
        <translation>Automaticky skrolovať názov piesne</translation>
    </message>
    <message>
        <location filename="../textscroller.cpp" line="118"/>
        <source>Buffering: %1%</source>
        <translation>Bufferuje sa:%1%</translation>
    </message>
</context>
<context>
    <name>VisualMenu</name>
    <message>
        <location filename="../visualmenu.cpp" line="29"/>
        <source>Visualization</source>
        <translation>Vizualizácie</translation>
    </message>
</context>
</TS>
